summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kcustommenueditor.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kio/kfile/kcustommenueditor.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kfile/kcustommenueditor.cpp')
-rw-r--r--kio/kfile/kcustommenueditor.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/kfile/kcustommenueditor.cpp b/kio/kfile/kcustommenueditor.cpp
index aec3c10f1..3b4e9a68c 100644
--- a/kio/kfile/kcustommenueditor.cpp
+++ b/kio/kfile/kcustommenueditor.cpp
@@ -57,8 +57,8 @@ public:
TQString serviceName = s->name();
// item names may contain ampersands. To avoid them being converted
- // to accelators, replace them with two ampersands.
- serviceName.replace("&", "&&");
+ // to accelators, tqreplace them with two ampersands.
+ serviceName.tqreplace("&", "&&");
TQPixmap normal = KGlobal::instance()->iconLoader()->loadIcon(s->icon(), KIcon::Small,
0, KIcon::DefaultState, 0L, true);
@@ -99,7 +99,7 @@ KCustomMenuEditor::KCustomMenuEditor(TQWidget *parent)
d->pbRemove=buttonBox->addButton(i18n("Remove"), this, TQT_SLOT(slotRemoveItem()));
d->pbMoveUp=buttonBox->addButton(i18n("Move Up"), this, TQT_SLOT(slotMoveUp()));
d->pbMoveDown=buttonBox->addButton(i18n("Move Down"), this, TQT_SLOT(slotMoveDown()));
- buttonBox->layout();
+ buttonBox->tqlayout();
connect( m_listView, TQT_SIGNAL( selectionChanged () ), this, TQT_SLOT( refreshButton() ) );
refreshButton();
}